@@ -535,7 +535,7 @@ class ER:
             self.__add_obj_copy(n1)
             if self.debug: print(" ")
 
-    def compareNodes(self, otherGraph, label = "", node_type = NodeType.NOT_SPECIFIED, scores={}, debug=False):
+    def compareGraphs(self, otherGraph, label = "", node_type = NodeType.NOT_SPECIFIED, scores={}, debug=False):
         if debug: debugging = True
         else: debugging = self.debug
         dist = 0
@@ -550,8 +550,8 @@ class ER:
                 print(f" » testing {n1['label']}:")
             if not otherGraph.has_node(n1["label"]):
                 if debugging:
-                    print(f"   ✗ {scores['missing_node']:+.2f}, node '{n1['label']}' doesn't exist in other graph")
-                dist += scores['missing_node']
+                    print(f"   ✗ {scores['missing_object']:+.2f}, object '{n1['label']}' doesn't exist in other graph")
+                dist += scores['missing_object']
             else:
                 # node exists, check equality
                 n2 = otherGraph.get_obj(n1["label"], node_type)
